==> google-cloud-sdk-298.0.0-darwin-x86_64.tar.gz: google-cloud-sdk/lib/surface/vmware/clusters/list.py <==
# -*- coding: utf-8 -*- #
# Copyright 2020 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""'vmware clusters list' command."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.api_lib.vmware.clusters import ClustersClient
from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.vmware import flags

DETAILED_HELP = {
    'DESCRIPTION':
        """
          list VMware clusters in a privatecloud.
        """,
    'EXAMPLES':
        """

      $ {command} --cluster-group=my-privatecloud

    """,
}


@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
class List(base.ListCommand):
  """List Cloud VMware clusters."""

  @staticmethod
  def Args(parser):
    """Register flags for this command."""
    flags.AddPrivatecloudArgToParser(parser)
    parser.display_info.AddFormat('table(name.segment(-1):label=NAME,'
                                  'name.segment(-5):label=PROJECT,'
                                  'name.segment(-3):label=PRIVATECLOUD,'
                                  'nodeCount,createTime,status)')

  def Run(self, args):
    privatecloud = args.CONCEPTS.privatecloud.Parse()
    client = ClustersClient()
    return client.List(privatecloud, limit=args.limit)


List.detailed_help = DETAILED_HELP

==> google-cloud-sdk-354.0.0-darwin-x86_64.tar.gz: google-cloud-sdk/lib/surface/vmware/clusters/list.py <==
# -*- coding: utf-8 -*- #
# Copyright 2021 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""'vmware clusters list' command."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.api_lib.vmware.clusters import ClustersClient
from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.vmware import flags


@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
class List(base.ListCommand):
  """List clusters in a Google VMware Engine private cloud."""

  @staticmethod
  def Args(parser):
    """Register flags for this command."""
    flags.AddPrivatecloudArgToParser(parser)
    parser.display_info.AddFormat('table(name.segment(-1):label=NAME,'
                                  'name.segment(-5):label=LOCATION,'
                                  'name.segment(-3):label=PRIVATECLOUD,'
                                  'nodeTypeId:label=NODE_TYPE,'
                                  'nodeCount,createTime,state)')

  def Run(self, args):
    privatecloud = args.CONCEPTS.privatecloud.Parse()
    client = ClustersClient()
    return client.List(privatecloud, limit=args.limit)


List.detailed_help = {
    'DESCRIPTION':
        """
          List clusters in a VMware Engine private cloud.
          """,
    'EXAMPLES':
        """
          To list clusters in the ``my-privatecloud'' private cloud run:

            $ {command} --location=us-west2-a --project=my-project --privatecloud=my-privatecloud

            Or:

            $ {command} --privatecloud=my-privatecloud

          In the second example, the project and location are taken from gcloud properties core/project and compute/zone.
    """,
}
